import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:flutter_svg/svg.dart';
import 'package:syncrow_web/pages/spaces_management/all_spaces/bloc/space_management_bloc.dart';
import 'package:syncrow_web/pages/spaces_management/all_spaces/bloc/space_management_event.dart';
import 'package:syncrow_web/pages/spaces_management/create_community/view/create_community_dialog.dart';
import 'package:syncrow_web/utils/color_manager.dart';
import 'package:syncrow_web/utils/constants/assets.dart';

class SidebarAddCommunityButton extends StatelessWidget {
  const SidebarAddCommunityButton({
    required this.existingCommunityNames,
    super.key,
  });

  final List<String> existingCommunityNames;

  @override
  Widget build(BuildContext context) {
    return SizedBox.square(
      dimension: 30,
      child: IconButton(
        style: IconButton.styleFrom(
          iconSize: 20,
          backgroundColor: ColorsManager.circleImageBackground,
          shape: const CircleBorder(
            side: BorderSide(
              color: ColorsManager.lightGrayBorderColor,
              width: 3,
            ),
          ),
        ),
        onPressed: () => _showCreateCommunityDialog(context),
        icon: SvgPicture.asset(Assets.addIcon),
      ),
    );
  }

  void _showCreateCommunityDialog(BuildContext context) => showDialog<void>(
        context: context,
        builder: (context) => CreateCommunityDialog(
          isEditMode: false,
          existingCommunityNames: existingCommunityNames,
          onCreateCommunity: (name, description) {
            context.read<SpaceManagementBloc>().add(
                  CreateCommunityEvent(name, description, context),
                );
          },
        ),
      );
}
